summaryrefslogtreecommitdiffstats
path: root/src/bluetooth/qbluetoothsocket_android.cpp
diff options
context:
space:
mode:
authorAlex Blasche <alexander.blasche@qt.io>2018-07-20 16:19:13 +0200
committerAlex Blasche <alexander.blasche@qt.io>2018-07-25 11:16:27 +0000
commit81de083e4f9fdee7f1ef7d2fffc7d2147ddbc1b0 (patch)
treefc6da5a446674330111930c6b9c0badadf0488aa /src/bluetooth/qbluetoothsocket_android.cpp
parente452269d918655c3aaf0d5759cf2143478661af5 (diff)
Rename QBluetoothSocketBasePrivate::connectToService()
The goal is to move the various QBluetoothSocket::connectoService() implementations into the private classes. Common parts can be split into QBluetoothSocketBasePrivate and the platform specific code. The code becomes cleaner and has less ifdefs. However this creates a symbol clash with the currently existing private implementation as it has a function with the same signature but different purpose. This rename provides the foundation for future changes. Task-number: QTBUG-68550 Change-Id: I121f08d93e00790c1619c0449629f47bca8a964d Reviewed-by: Lubomir I. Ivanov <neolit123@gmail.com> Reviewed-by: Oliver Wolff <oliver.wolff@qt.io>
Diffstat (limited to 'src/bluetooth/qbluetoothsocket_android.cpp')
-rw-r--r--src/bluetooth/qbluetoothsocket_android.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/bluetooth/qbluetoothsocket_android.cpp b/src/bluetooth/qbluetoothsocket_android.cpp
index 42fe4ff4..109d3141 100644
--- a/src/bluetooth/qbluetoothsocket_android.cpp
+++ b/src/bluetooth/qbluetoothsocket_android.cpp
@@ -403,31 +403,31 @@ bool QBluetoothSocketPrivateAndroid::fallBackReversedConnect(const QBluetoothUui
}
/*
* The call order during a connectToService() is as follows:
*
- * 1. call connectToService()
+ * 1. call connectToServiceHelper()
* 2. wait for execution of SocketConnectThread::run()
* 3. if threaded connect succeeds call socketConnectSuccess() via signals
* -> done
* 4. if threaded connect fails call defaultSocketConnectFailed() via signals
* 5. call fallBackConnect() if Android version 22 or below
* -> Android 23+ complete failure of entire connectToService()
* 6. call fallBackReversedConnect() if Android version 23 or above
* -> if failure entire connectToService() fails
* 7. if threaded connect on one of above fallbacks succeeds call socketConnectSuccess()
* via signals
* -> done
* 8. if threaded connect on fallback channel fails call fallbackSocketConnectFailed()
* -> complete failure of entire connectToService()
* */
-void QBluetoothSocketPrivateAndroid::connectToService(const QBluetoothAddress &address,
+void QBluetoothSocketPrivateAndroid::connectToServiceHelper(const QBluetoothAddress &address,
const QBluetoothUuid &uuid,
QIODevice::OpenMode openMode)
{
Q_Q(QBluetoothSocket);
Q_UNUSED(openMode);
- qCDebug(QT_BT_ANDROID) << "connectToService()" << address.toString() << uuid.toString();
+ qCDebug(QT_BT_ANDROID) << "connectToServiceHelper()" << address.toString() << uuid.toString();
q->setSocketState(QBluetoothSocket::ConnectingState);
@@ -403,31 +403,31 @@ bool QBluetoothSocketPrivateAndroid::fallBackReversedConnect(const QBluetoothUui
}
/*
- * The call order during a connectToService() is as follows:
+ * The call order during a connectToServiceHelper() is as follows:
*
@@ -403,31 +403,31 @@ bool QBluetoothSocketPrivateAndroid::fallBackReversedConnect(const QBluetoothUui
* 4. if threaded connect fails call defaultSocketConnectFailed() via signals
* 5. call fallBackConnect() if Android version 22 or below
- * -> Android 23+ complete failure of entire connectToService()
+ * -> Android 23+ complete failure of entire connectToServiceHelper()
* 6. call fallBackReversedConnect() if Android version 23 or above
@@ -403,31 +403,31 @@ bool QBluetoothSocketPrivateAndroid::fallBackReversedConnect(const QBluetoothUui
* 6. call fallBackReversedConnect() if Android version 23 or above
- * -> if failure entire connectToService() fails
+ * -> if failure entire connectToServiceHelper() fails
* 7. if threaded connect on one of above fallbacks succeeds call socketConnectSuccess()
* via signals
@@ -403,31 +403,31 @@ bool QBluetoothSocketPrivateAndroid::fallBackReversedConnect(const QBluetoothUui
* -> done
* 8. if threaded connect on fallback channel fails call fallbackSocketConnectFailed()
- * -> complete failure of entire connectToService()
+ * -> complete failure of entire connectToServiceHelper()
* */